@@ -56,7 +56,7 @@ logging_config = {
             "filters": ["hostname", "source_ip", "concurrent_id"]
         },
         "file": {
-            'level': 'INFO',
+            'level': 'DEBUG',
             "class": "logging.handlers.TimedRotatingFileHandler",
             "filename": os.path.join(log_dir, "log.log"),
             "formatter": "winhye",
@@ -74,7 +74,7 @@ logging_config = {
     },
     "loggers": {
         "": {
-            "level": "INFO",  # logger日志输出级别
+            "level": "DEBUG",  # logger日志输出级别
             "handlers": ["console", "file", "watch_handler"],
             'propagate': True
         },
