@@ -1,11 +1,12 @@
 import os
 import sys
+import time
 
-PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)), "src")
+PATH = os.path.abspath(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
 sys.path.append(PATH)
 print(PATH)
 
-from winhye_common.mqtt.mqtt_base import MqttClint
+from src.winhye_common.mqtt.mqtt_base import MqttClint, MqttSendMessageException
 
 
 def mqtt_test():
@@ -27,7 +28,13 @@ def mqtt_test():
         }
     }
     handler = MqttClint(mqtt_config)
-    handler.send_message("reported_kaifa/AGV-S/aa", data)
+    time.sleep(1)
+    try:
+        while True:
+            handler.send_message("send_kaifa/AGV-S/aa", data)
+            time.sleep(60)
+    except MqttSendMessageException:
+        print(111111111111111111)
 
 
 if __name__ == '__main__':
